# GUI (Screens)
from Screens.Screen import Screen
from Components.ConfigList import ConfigListScreen

# GUI (Summary)
from Screens.Setup import SetupSummary
from Screens.MessageBox import MessageBox

# GUI (Components)
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText

# Configuration
from Components.config import config, getConfigListEntry

version_txt = "1.1"

class StartupToIdleConfiguration(Screen, ConfigListScreen):
	"""Configuration of Startup To Idle"""

	def __init__(self, session):
		Screen.__init__(self, session)
		self.skinName = [ "StartupToIdleConfiguration", "Setup" ]

		# Summary
		self.setup_title = _("StartupToIdle Configuration") + " v" + version_txt
		self.onChangedEntry = []

		# Buttons
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))

		# Define Actions
		self["actions"] = ActionMap(["SetupActions", "TimerEditActions"],
			{
				"cancel": self.keyCancel,
				"save": self.keySave,
				"log": self.showLastStartLog,
			}
		)

		self.list = []
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changed)

		self.createSetup()
		self.onLayoutFinish.append(self.layoutFinished)

	def layoutFinished(self):
		self.setTitle(self.setup_title)

	def createSetup(self):
		self.list = []
		self.list.append(getConfigListEntry(_("startup to idle mode"), config.plugins.startuptoidle.enabled))
		if config.plugins.startuptoidle.enabled.value == "crashOnIdle":
			self.list.append(getConfigListEntry(_("after manual Restart GUI/Restart going to"), config.plugins.startuptoidle.onManualRestart))
		self.list.append(getConfigListEntry(_("debug options")))
		self.list.append(getConfigListEntry(_("activate consolen debug output"), config.plugins.startuptoidle.showdebuginfo))
		self.list.append(getConfigListEntry(_("save startlog to /tmp"), config.plugins.startuptoidle.savestartlog))
		self["config"].setList(self.list)

	def changed(self):
		cur = self["config"].getCurrent()
		if cur and cur[1] == config.plugins.startuptoidle.enabled:
			self.createSetup()
		for x in self.onChangedEntry:
			x()

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		return SetupSummary
	
	def showLastStartLog(self):
		from plugin import lastStartLog
		self.session.open(MessageBox,lastStartLog,MessageBox.TYPE_INFO,title="StartupToIdle - last startup log")

